@@ -1,12 +1,10 @@
 #' @importFrom stats as.formula
 #' @importFrom data.table as.data.table dcast.data.table setorderv
-#' @importFrom htmltools htmlEscape
 shape_as_series <- function(x){
   dataset <- as.data.table(x$data)
   dataset <- setorderv(dataset, c(x$x, x$group) )
 
   if( !is.null(x$group)){
-    dataset[[x$group]] <- htmlEscape(dataset[[x$group]])
     form_str <- sprintf("%s ~ %s", x$x, x$group)
     dataset <- dcast.data.table(dataset, formula = as.formula(form_str),
                                 fun.aggregate = function(x) {x},
@@ -18,7 +16,6 @@ shape_as_series <- function(x){
 }
 
 
-
 fmt_name <- function( x ){
 
   if( inherits(x, "Date") )
@@ -37,13 +34,13 @@ fmt_name <- function( x ){
 serie_builtin_class <- function( x ){
 
   if( inherits(x, "Date") )
-    str_ref
+    date_ref(x)
   else if( is.factor(x) || is.character(x) )
-    str_ref
+    str_ref(x)
   else if( is.integer(x) )
-    num_ref
+    num_ref(x)
   else if( is.double(x) )
-    num_ref
+    num_ref(x)
   else stop("unknow type of data")
 }
 
